/*****************************************************************************/
/* FILENAME                                                                  */
/*   FIR_filters.c                                                           */
/*                                                                           */
/* DESCRIPTION                                                               */
/*   Finite Impulse Response Filters using the TMS320C5510 DSK.              */
/*                                                                           */
/*  Rev 1.00   Richard Sikora                                                */
/*                                                                           */
/*---------------------------------------------------------------------------*/
/*  HISTORY                                                                  */
/*  Rev 1.00                                                                 */
/*  31st January 2005. Created by Richard Sikora from TMS320C5416 code.      */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/

#include <stdio.h>

#define FIR_FILTER_SIZE 51

/*****************************************************************************/
/* FIR_filter()                                                              */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/* INPUTS: 1st parameter. Address of array of filter constants.              */
/*         2nd parameter. Latest input to filter                             */
/*                                                                           */
/* RETURNS: Output of FIR filter                                             */
/*                                                                           */ 
/*****************************************************************************/ 

static int value[FIR_FILTER_SIZE]; /* Retain value between calls */                                                                             
signed int i;  /* Index into filter constants */ 
static signed int j = 0; /* Index into input array */
long product;
                                                                             
short int FIR_filter(signed int * filter_constants, signed int input)
{
 product = 0;
 
 for ( i = 0 ; i < FIR_FILTER_SIZE ; i++)
 {
  /* Generate sum of products. Shift right to prevent overflow */
  /* This is first part of divide by 32767 */
  
  product +=  ( ((long) value[j] * filter_constants[i]) >> 5);
  
  if ( j < FIR_FILTER_SIZE-1) /* Next item in circular buffer */
    { 
     j++;
    }                      
  else
    {
     j = 0;                    /* Go back to beginning of buffer */  
    }
 }
 
 if ( j < FIR_FILTER_SIZE -1) /* Loop done. Last filter element */
    {
     j++;
    }
 else
    {
     j = 0;   /* Point to new value */
    }

 product >>= 10;   /* Second part of divide by 32768 */
    
 value[j] = input; /* Read in new value for next time. */
 
 return( (signed int) product); 
}        


/***************************************************************************/
/* End of FIR_filters.c                                                    */
/***************************************************************************/

  









