/*****************************************************************************/
/*                                                                           */
/* FILENAME                                                                  */
/*   reverberation.c                                                         */
/*                                                                           */
/* DESCRIPTION                                                               */
/*   TMS320C6713 DSK. Reverberation based on 100 ms delay.                   */
/*                                                                           */
/* REVISION                                                                  */
/*   Revision: 1.00                                                          */
/*   Author  : Richard Sikora                                                */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/* HISTORY                                                                   */
/*   Revision 1.00                                                           */
/*   6th January 2005. Created by Richard Sikora from C6711 code.            */
/*                                                                           */
/*****************************************************************************/

#define N 10000

/* IMPORTANT. The following must be declared as 'far' othewise link fails */

signed far int reverberation_array[N]; /* Buffer for maximum of 100 ms delay */

/*****************************************************************************/
/* reverberation_array_clear()                                               */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/* Fill reverberation_array[] used for reverberation with zeroes to prevent  */
/* noise and clicks.                                                         */
/*                                                                           */
/*****************************************************************************/

void reverberation_array_clear(void)
{
 int i;
 
 for ( i = 0 ; i < N ; i++)
  {
   reverberation_array[i] = 0;
  }
}

/*****************************************************************************/
/* reverberation()                                                           */
/*****************************************************************************/

signed int reverberation( signed int latest_input)
{
 static signed int index = 0; /* Retain value between calls */
 signed long temp;
 signed long oldest_input;
 

 oldest_input = (long) (reverberation_array[index] * 25000); /* Scale oldest sample */
 
 oldest_input >>= 15; /* Remove fractional part */
 
 temp = (long) latest_input + oldest_input; /* Newest + oldest */

 temp >>= 1;  /* Divide by two */
 
 if ( temp > 32767) /* Limit positive to maximum in case of overload */
   {
    temp = 32767;
   } 
 else if ( temp < -32767) /* Limit negative to minimum */
   { 
    temp = -32767;
   }
 
 reverberation_array[index] = temp; /* Overwrite buffer with new value */
 
 if ( index < N - 1)  /* Increment index if not at end of buffer */
   {
    index++;
   }  
 else
   {
    index = 0;  /* Otherwise go back to beginning of buffer */
   }
   
 return( (signed int) temp); /* Return new output */

}

/*****************************************************************************/
/* End of reverberation.c                                                    */
/*****************************************************************************/
