/*****************************************************************************/
/*                                                                           */
/* FILENAME                                                                  */
/*  fuzz.c                                                                   */
/*                                                                           */
/* DESCRIPTION                                                               */
/*   TMS320C5510 DSK. Fuzz guitar effect. Causes waveform to be clipped.     */
/*                                                                           */
/* REVISION                                                                  */
/*   Revision: 1.00                                                          */
/*   Author  : Richard Sikora                                                */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/* HISTORY                                                                   */
/*   Revision 1.00                                                           */
/*   27th January 2005. Created by Richard Sikora from C6711 code.           */
/*                                                                           */
/*****************************************************************************/


/*****************************************************************************/
/* fuzz()                                                                    */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/* For inputs with amplitude less than 500, give system high gain.           */
/* For inputs with amplitude greater than 500, make the output the value     */
/* set by Y.                                                                 */
/*                                                                           */
/*****************************************************************************/

#define X 500
#define Y 15000

#define GRADIENT (Y/X)

signed int fuzz( signed int input)
{
 signed long output;

 if ( (input > -X) && (input < X) )
  {
   /* Input amplitude lies between -500 and +500 */
  
   output = GRADIENT * (long) input  ;
  }
 else if ( input < 0)
  {
   /* Input amplitude is less than -500 */
  
   output = -Y;
  }
 else
  {
   /* Input amplitude is greater than +500 */
  
   output = Y;
  }

 output >>= 3; /* Reduce output volume */

 /* Limit output between -32767 and +32767 in case of overload */

 if ( output > 32767)
  {
   output = 32767;
  } 
 else if ( output < -32767)
  {
   output = - 32767;  
  }
   
 return( (signed int)output );
}                 


/*****************************************************************************/
/* End of fuzz.c                                                             */
/*****************************************************************************/
